==> modonomicon-1.20.1-fabric-1.79.1-sources.jar: com/klikli_dev/modonomicon/networking/SaveEntryStateMessage.java <==
/*
 * SPDX-FileCopyrightText: 2022 klikli-dev
 *
 * SPDX-License-Identifier: MIT
 */

package com.klikli_dev.modonomicon.networking;

import com.klikli_dev.modonomicon.Modonomicon;
import com.klikli_dev.modonomicon.book.entries.*;
import com.klikli_dev.modonomicon.bookstate.BookVisualStateManager;
import com.klikli_dev.modonomicon.bookstate.visual.EntryVisualState;
import com.klikli_dev.modonomicon.data.BookDataManager;
import net.minecraft.class_2540;
import net.minecraft.class_2960;
import net.minecraft.class_3222;
import net.minecraft.server.MinecraftServer;

public class SaveEntryStateMessage implements Message {

    public static final class_2960 ID = new class_2960(Modonomicon.MOD_ID, "save_entry_state");

    public BookEntry entry;
    public int openPagesIndex;

    public SaveEntryStateMessage(ContentBookEntry entry, int openPagesIndex) {
        this.entry = entry;
        this.openPagesIndex = openPagesIndex;
    }

    public SaveEntryStateMessage(class_2540 buf) {
        this.decode(buf);
    }

    @Override
    public void encode(class_2540 buf) {
        buf.method_10812(this.entry.getBook().getId());
        buf.method_10812(this.entry.getId());
        buf.method_10804(this.openPagesIndex);
    }

    @Override
    public void decode(class_2540 buf) {
        this.entry = BookDataManager.get().getBook(buf.method_10810()).getEntry(buf.method_10810());
        this.openPagesIndex = buf.method_10816();
    }

    @Override
    public class_2960 getId() {
        return ID;
    }

    @Override
    public void onServerReceived(MinecraftServer minecraftServer, class_3222 player) {
        var currentState = BookVisualStateManager.get().getEntryStateFor(player, this.entry);
        currentState.openPagesIndex = this.openPagesIndex;
        BookVisualStateManager.get().setEntryStateFor(player, this.entry, currentState);
        BookVisualStateManager.get().syncFor(player);
    }
}

==> modonomicon-1.21.10-fabric-1.119.0-sources.jar: com/klikli_dev/modonomicon/networking/SaveEntryStateMessage.java <==
/*
 * SPDX-FileCopyrightText: 2022 klikli-dev
 *
 * SPDX-License-Identifier: MIT
 */

package com.klikli_dev.modonomicon.networking;

import com.klikli_dev.modonomicon.Modonomicon;
import com.klikli_dev.modonomicon.book.entries.BookEntry;
import com.klikli_dev.modonomicon.bookstate.BookVisualStateManager;
import com.klikli_dev.modonomicon.bookstate.visual.EntryVisualState;
import com.klikli_dev.modonomicon.data.BookDataManager;
import net.minecraft.class_2960;
import net.minecraft.class_3222;
import net.minecraft.class_8710;
import net.minecraft.class_9129;
import net.minecraft.class_9139;
import net.minecraft.server.MinecraftServer;

public class SaveEntryStateMessage implements Message {

    public static final class_9154<SaveEntryStateMessage> TYPE = new class_9154<>(class_2960.method_60655(Modonomicon.MOD_ID, "save_entry_state"));

    public static final class_9139<class_9129, SaveEntryStateMessage> STREAM_CODEC = class_8710.method_56484(SaveEntryStateMessage::encode, SaveEntryStateMessage::new);


    public BookEntry entry;
    public int openPagesIndex;

    public SaveEntryStateMessage(BookEntry entry, EntryVisualState state) {
        this(entry, state.openPagesIndex);
    }

    public SaveEntryStateMessage(BookEntry entry, int openPagesIndex) {
        this.entry = entry;
        this.openPagesIndex = openPagesIndex;
    }

    public SaveEntryStateMessage(class_9129 buf) {
        this.decode(buf);
    }

    private void encode(class_9129 buf) {
        buf.method_10812(this.entry.getBook().getId());
        buf.method_10812(this.entry.getId());
        buf.method_10804(this.openPagesIndex);
    }

    private void decode(class_9129 buf) {
        this.entry = BookDataManager.get().getBook(buf.method_10810()).getEntry(buf.method_10810());
        this.openPagesIndex = buf.method_10816();
    }

    @Override
    public class_9154<? extends class_8710> method_56479() {
        return TYPE;
    }

    @Override
    public void onServerReceived(MinecraftServer minecraftServer, class_3222 player) {
        var currentState = BookVisualStateManager.get().getEntryStateFor(player, this.entry);
        currentState.openPagesIndex = this.openPagesIndex;
        BookVisualStateManager.get().setEntryStateFor(player, this.entry, currentState);
        BookVisualStateManager.get().syncFor(player);
    }
}
